@@ -1,6 +1,7 @@
 from sprox.sprockets import Sprocket, SprocketCache, ConfigCache, FillerCache, ViewCache, ConfigCacheError
 from sprox.test.base import setup_database, sorted_user_columns, SproxTest, User
 from nose.tools import raises, eq_
+from strainer.operators import assert_in_xhtml
 
 session = None
 engine  = None
@@ -26,9 +27,21 @@ class TestViewCache(SproxTest):
         base = self.cache['model_view']
         eq_(base(), """<div xmlns="http://www.w3.org/1999/xhtml" class="containerwidget">
 <div class="entitylabelwidget">
+<a href="Department/">Department</a>
+</div>
+<div class="entitylabelwidget">
 <a href="Document/">Document</a>
 </div>
 <div class="entitylabelwidget">
+<a href="DocumentCategory/">DocumentCategory</a>
+</div>
+<div class="entitylabelwidget">
+<a href="DocumentCategoryReference/">DocumentCategoryReference</a>
+</div>
+<div class="entitylabelwidget">
+<a href="DocumentCategoryTag/">DocumentCategoryTag</a>
+</div>
+<div class="entitylabelwidget">
 <a href="Example/">Example</a>
 </div>
 <div class="entitylabelwidget">
@@ -51,39 +64,21 @@ class TestViewCache(SproxTest):
     def test_get_empty(self):
         base = self.cache['listing__User']
         b = base()
-        assert """<table class="grid">
-    <thead>
+        assert_in_xhtml("""<thead>
         <tr>
-            <th class="col_0">
-            actions
-            </th><th class="col_1">
-            _password
-            </th><th class="col_2">
-            user_id
-            </th><th class="col_3">
-            user_name
-            </th><th class="col_4">
-            email_address
-            </th><th class="col_5">
-            display_name
-            </th><th class="col_6">
-            created
-            </th><th class="col_7">
-            town_id
-            </th><th class="col_8">
-            town
-            </th><th class="col_9">
-            password
-            </th><th class="col_10">
-            groups
-            </th>
+                <th  class="col_0">actions</th>
+                <th  class="col_1">_password</th>
+                <th  class="col_2">user_id</th>
+                <th  class="col_3">user_name</th>
+                <th  class="col_4">email_address</th>
+                <th  class="col_5">display_name</th>
+                <th  class="col_6">created</th>
+                <th  class="col_7">town_id</th>
+                <th  class="col_8">town</th>
+                <th  class="col_9">password</th>
+                <th  class="col_10">groups</th>
         </tr>
-    </thead>
-    <tbody>
-    </tbody>
-</table>
-      No Records Found.
-</div>""" in b, b
+    </thead>""" , b)
 
     @raises(ConfigCacheError)
     def get_not_found(self):
